@@ -28,6 +28,7 @@ from teslajsonpy.const import (
     SLEEP_INTERVAL,
     TESLA_PRODUCT_TYPE_ENERGY_SITES,
     TESLA_PRODUCT_TYPE_VEHICLES,
+    TESLA_DEFAULT_ENERGY_SITE_NAME,
 )
 from teslajsonpy.exceptions import should_giveup, RetryLimitError, TeslaException
 from teslajsonpy.homeassistant.battery_sensor import Battery, Range
@@ -50,7 +51,7 @@ from teslajsonpy.homeassistant.lock import ChargerLock, Lock
 from teslajsonpy.homeassistant.sentry_mode import SentryModeSwitch
 from teslajsonpy.homeassistant.trunk import FrunkLock, TrunkLock
 from teslajsonpy.homeassistant.heated_steering_wheel import HeatedSteeringWheelSwitch
-from teslajsonpy.homeassistant.power import PowerSensor, TESLA_DEFAULT_ENEREGY_SITE_NAME
+from teslajsonpy.homeassistant.power import PowerSensor
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -148,7 +149,7 @@ async def wake_up(wrapped, instance, args, kwargs) -> Callable:
     is_wake_command = False
     is_energysite_command = False
     if wrapped.__name__ == "api":
-        car_id = kwargs.get("vehicle_id", "")
+        car_id = kwargs.get("path_vars", {}).get("vehicle_id", "")
     else:
         car_id = args[0] if not kwargs.get("vehicle_id") else kwargs.get("vehicle_id")
         is_wake_command = len(args) >= 2 and args[1] == "wake_up"
@@ -168,8 +169,15 @@ async def wake_up(wrapped, instance, args, kwargs) -> Callable:
             _LOGGER.debug(
                 "Exception: %s\n%s(%s %s)", str(ex), wrapped.__name__, args, kwargs
             )
+            if ex.code == 408 and car_id and instance._id_to_vin(car_id):
+                instance.car_online[instance._id_to_vin(car_id)] = False
             raise
-    if valid_result(result) or is_wake_command or is_energysite_command or instance._id_to_vin(car_id) is None:
+    if (
+        valid_result(result)
+        or is_wake_command
+        or is_energysite_command
+        or instance._id_to_vin(car_id) is None
+    ):
         return result
     _LOGGER.debug(
         "wake_up needed for %s -> %s \n"
@@ -329,7 +337,7 @@ class Controller:
         self._last_attempted_update_time = time.time()
         self.__update_lock = asyncio.Lock()
 
-        energysites = await self.get_energysites()
+        self.energysites = await self.get_energysites()
 
         for car in cars:
             vin = car["vin"]
@@ -359,23 +367,21 @@ class Controller:
 
             self._add_car_components(car)
 
-        for energysite in energysites:
+        for energysite in self.energysites:
             energysite_id = energysite["energy_site_id"]
             self.__id_energysiteid_map[energysite["id"]] = energysite_id
             self.__energysiteid_id_map[energysite_id] = energysite["id"]
-            self.__energysite_name[energysite_id] = energysite.get("site_name", TESLA_DEFAULT_ENEREGY_SITE_NAME)
+            self.__energysite_name[energysite_id] = energysite.get(
+                "site_name", TESLA_DEFAULT_ENERGY_SITE_NAME
+            )
             self.__energysite_type[energysite_id] = energysite["solar_type"]
             self.__power[energysite_id] = {"solar_power": energysite["solar_power"]}
             self.__lock[energysite_id] = asyncio.Lock()
             self._add_energysite_components(energysite)
 
         if not test_login:
-            tasks = [
-                self.update(car["id"], wake_if_asleep=wake_if_asleep) for car in cars
-            ]
-            _LOGGER.debug("tasks %s %s", tasks, wake_if_asleep)
             try:
-                await asyncio.gather(*tasks)
+                await self.update(wake_if_asleep=wake_if_asleep)
             except (TeslaException, RetryLimitError):
                 pass
         return {
@@ -462,7 +468,7 @@ class Controller:
 
     @backoff.on_exception(min_expo, httpx.RequestError, max_time=10, logger=__name__)
     async def get_energysites(self):
-        """Get energy sites json from TeslaAPI."""
+        """Get energy sites json from TeslaAPI and filter to solar."""
         return [
             p
             for p in (await self.api("PRODUCT_LIST"))["response"]
@@ -694,13 +700,15 @@ class Controller:
         force: bool = False,
     ) -> bool:
         #  pylint: disable=too-many-locals,too-many-statements
-        """Update all vehicle attributes in the cache.
+        """Update all vehicle and energy site attributes in the cache.
 
         This command will connect to the Tesla API and first update the list of
         online vehicles assuming no attempt for at least the [update_interval].
         It will then update all the cached values for cars that are awake
         assuming no update has occurred for at least the [update_interval].
 
+        For energy sites, they will only be updated if car_id is blank.
+
         Args
             car_id (Text, optional): The vehicle to update. If None, all cars are updated. Defaults to None.
             wake_if_asleep (bool, optional): force a vehicle awake. This is processed by the wake_up decorator. Defaults to False.
@@ -822,7 +830,7 @@ class Controller:
 
         async def _get_and_process_energysite_data(energysite_id: Text) -> None:
             async with self.__lock[energysite_id]:
-                _LOGGER.debug("Updating %s", energysite_id)
+                _LOGGER.debug("Updating energysite %s", energysite_id)
                 try:
                     data = await self.api(
                         "SITE_DATA",
@@ -851,8 +859,6 @@ class Controller:
                     self.car_state[car["vin"]] = car
                 self._last_attempted_update_time = cur_time
 
-                self.energysites = {}
-                self.energysites = await self.get_energysites()
             # Only update online vehicles that haven't been updated recently
             # The throttling is per car's last succesful update
             # Note: This separate check is because there may be individual cars
@@ -890,10 +896,10 @@ class Controller:
                         _LOGGER.debug(
                             "Skipping update of %s with state %s", vin[-5:], car_state
                         )
-
-            for energysite in self.energysites:
-                energysite_id = energysite["energy_site_id"]
-                async with self.__lock[energysite_id]:
+            if not car_id:
+                # do not update energy sites if car_id was a parameter.
+                for energysite in self.energysites:
+                    energysite_id = energysite["energy_site_id"]
                     tasks.append(_get_and_process_energysite_data(energysite_id))
 
             return any(await asyncio.gather(*tasks))
